define('aim/absence/view/BoardMainView',['aim/util/Utils',
                                         'aim/absence/model/ChangePlanValueModel',
                                         'aim/absence/model/AbsenceValueModel',
                                         'aim/absence/view/SelectCalendarWeekView',
                                         'aim/absence/view/AbsenceValueView'
                                         ], function(Utils,ChangePlanValueModel,AbsenceValueModel,SelectCalendarWeekView,AbsenceValueView) {
	var BoardMainView = Backbone.View.extend({
		el : "#content",
		
		events: {
			"click #dialog-add-absence-button" : "addAbsenceValues",
			"click #calendar-weeks-shift-left-button" : "calendarWeeksShiftLeft",
			"click #calendar-weeks-shift-right-button" : "calendarWeeksShiftRight",
			"change .inputweeks" : "edit",
			"change #calendar-week-select" : "jumpToCalendarWeek"
		},
		
		context : {},
		
		initialize : function() {
			var requests = new Array();
			AJS.$.ajaxSetup({
				beforeSend:function(event,xhr,options){
					requests.push(xhr);
					if(xhr.url.endsWith("/context") ){
						AJS.$('.spinner').spin();
						AJS.$('.spinner').addClass('naomi-spinner');
					}
				},
				complete:function(xhr,status){
					requests.pop(xhr);
					if(requests.length == 0){
						AJS.$('.spinner').spinStop();
						AJS.$('.spinner').removeClass('naomi-spinner');
					}
				}
			});	
			this.listenTo(this.model, 'sync', this.render);
			this.absenceValueModel = new AbsenceValueModel();
			var selectCalendarWeekView = new SelectCalendarWeekView({model: this.model});
			this.model.fetch();
			this.fieldsInError = new Array();
		},
		
		render : function() {
			focusedElementId = AJS.$(':focus').attr('id');
			var tmpOps = {};
			tmpOps.currentWeek = this.model.get('highlightedWeek');
			var pagePanelInner = this.$('#aui-page-panel-inner');
			pagePanelInner.html(Naomi.Templates.AbsenceBoard.board(tmpOps, null, this.model.get('context')));
		    AJS.$('#' + focusedElementId).focus();
		    AJS.$('#' + focusedElementId).select();
			if( ! this.model.attributes.errorMessage && ! this.model.attributes.warnMessage && ! this.model.attributes.infoMessage && this.fieldsInError.length == 0){
				Utils.clearMessageBar('#add-dialog-message-bar');
			}
		    return this;
		},
			
		addAbsenceValues : function() {
			this.absenceValueModel.set('operation','initializeDialogValues');
			this.absenceValueModel.set('currentCalendarWeek', this.model.attributes.currentCalendarWeek);
			if( ! this.absenceValueView)
				this.absenceValueView = new AbsenceValueView({model: this.absenceValueModel, contextModel: this.model});
			this.absenceValueModel.save();
			AJS.dialog2("#add-absence-dialog").show();
		},
		
		calendarWeeksShiftLeft : function() {
			this.model.set("calendarWeekShift",-1);
			this.model.set("operation","shiftCalendarWeek");
			this.model.save();
		},
		
		calendarWeeksShiftRight : function() {
			this.model.set("calendarWeekShift",1);
			this.model.set("operation","shiftCalendarWeek");
			this.model.save();
		},
		
		jumpToCalendarWeek : function(event) {
			this.model.set("calendarWeekShift",event.currentTarget.value);
			this.model.set("operation","shiftCalendarWeek");
			this.model.save();
		},
		
		edit: function(event) {
			var that = this;
			if(event && event.currentTarget && event.currentTarget.id) {
				if(!event.currentTarget.value) return;
				var longResourceId = event.currentTarget.dataset.longresourceid;
				var resourceId = event.currentTarget.dataset.resourceid;
				var weekId = event.currentTarget.dataset.weekid;
				var weeks = this.model.attributes.context.weeks;
				var year = event.currentTarget.dataset.year;
				var fieldHolder = this.fieldsInError;
				var selector = '#'+event.currentTarget.id;
				var modelForSave = new ChangePlanValueModel();
				modelForSave.set('selectedResource', longResourceId);
				modelForSave.set('year', year);
				modelForSave.set('week', weekId);
				modelForSave.set('operation', "spreadInWeek");
				modelForSave.set('planValue', event.currentTarget.value);
				modelForSave.save(null, {success:function(model, res, options) {
					var context = that.model.attributes.context;
					if( Utils.validateFlagModel(model,'naomi.templates.js.jirarp.board.message', selector, fieldHolder) ){
						var result = res;
						var kw = _.find(context.weeks, function(week) {
							if(week.title == weekId) {
								return true;
							} else {
								return false;
							}
						}); 
						var restSum = result.resourceRestSum;
						var inputValue = result.planValue;
						kw.resourceSubSections[resourceId].sum = inputValue;
						that.render();
						if( res.errorMessage || res.warnMessage || res.infoMessage ){
							//in this case the validate model has sent a message, keep quite
						}else{
							var title= AJS.I18n.getText("naomi.templates.js.jirarp.absence.board.message.saved.value.title");
							var replacements = {'%VALUE%': inputValue+'','%USER%': model.attributes.changedResource.displayName, '%WEEK%': weekId};
							var text = AJS.I18n.getText("naomi.templates.js.jirarp.absence.board.message.saved.value.message");
							var message = Utils.replace(replacements,text);
							Utils.sendMessage('success',title,'auto',message);
							Utils.unmarkField(selector, fieldHolder);
						}
					}
					
				},error:function(model, res, options) {
					var title= AJS.I18n.getText("naomi.templates.js.jirarp.absence.board.message.error.value.title");
					var text = AJS.I18n.getText("naomi.templates.js.jirarp.absence.board.message.error.value.message");
					var responseMessage = jQuery.parseJSON(res.responseText);
					var replacements = {'%VALUE%': event.currentTarget.value+'','%RESPONSE_MESSAGE%' : responseMessage.message};
					var message = Utils.replace(replacements,text);
					Utils.sendMessage('error',title,'manual',message);
					Utils.markFieldWithError(selector, fieldHolder);

				}});
			}
		}
	});
	return BoardMainView;
});