define('aim/assignment/view/PlanValueView',['aim/util/Utils',
                                            'aim/assignment/view/SelectDistributionView',
                                            'aim/assignment/view/SelectProjectView',
                                            'aim/assignment/view/SelectResourceView',
                                            'aim/assignment/view/SelectFromView',
                                            'aim/assignment/view/SelectToView',
                                            'aim/assignment/view/SelectRestValueView',
                                            'aim/assignment/view/SelectCapacityValueView',
                                            'aim/assignment/view/ExtendFilterView',
                                            'aim/assignment/view/CalendarWeeksView',
                                            'aim/assignment/view/CalendarWeeksWithCapacityView',
                                            'aim/assignment/view/CalendarWeeksWithAvailabilityView',
                                            'aim/assignment/view/DaysWithCapacityView',
                                            'aim/assignment/view/DaysWithAvailabilityView'
                                            ], function(
                                            		Utils,
                                            		SelectDistributionView,
                                            		SelectProjectView,
                                            		SelectResourceView,
                                            		SelectFromView,
                                            		SelectToView,
                                            		SelectRestValueView,
                                            		SelectCapacityValueView,
                                            		ExtendFilterView,
                                            		CalendarWeeksView,
                                            		CalendarWeeksWithCapacityView,
                                            		CalendarWeeksWithAvailabilityView,
                                            		DaysWithCapacityView,
                                            		DaysWithAvailabilityView
                                            ) {
	var PlanValueView = Backbone.View.extend({
		
		el : '#add-plan-value-dialog',
		
		events: {
			"change #product-single-select" : "projectSelectChanged",
			"change #resource-single-select" : "resourceSelectChanged",
			"change #distribution-single-select" : "distributionSelectChanged",
			"change #fromDate" : "fromChanged",
			"change #toDate" : "toChanged",
			"change #planValue" : "planValueChanged",
			"click #planvalues-save-button" : "savePlanValues",
			"click #planvalues-cancel-button" : "cancelPlanValues"
		},
		
		initialize : function() {
			this.listenTo(this.model, 'sync', this.render);
			var selectDistributionView = new SelectDistributionView({model: this.model});
			var selectProjectView = new SelectProjectView({model: this.model});
			var selectResourceView = new SelectResourceView({model: this.model});
			var selectedFromDate = new SelectFromView({model: this.model});
			var selectedToDate = new SelectToView({model: this.model});
			var selectedRestValue = new SelectRestValueView({model: this.model});
			var selectedCapacityValue = new SelectCapacityValueView({model: this.model});
			var extendFilterView = new ExtendFilterView({model: this.model});
			var calendarWeeksView = new CalendarWeeksView({model: this.model});
			var calendarWeeksWithCapacityView = new CalendarWeeksWithCapacityView({model: this.model});
			var calendarWeeksWithAvailabilityView = new CalendarWeeksWithAvailabilityView({model: this.model});
			var daysWithCapacityView = new DaysWithCapacityView({model: this.model});
			var daysWithAvailabilityView = new DaysWithAvailabilityView({model: this.model});
			this.fieldsInError = new Array();
		},
		
		render : function() {
			AJS.$("#planValue").attr("value", this.model.get('planValue'));
			if( ! this.model.attributes.errorMessage && ! this.model.attributes.warnMessage && ! this.model.attributes.infoMessage){
				Utils.clearMessageBar('#add-dialog-message-bar');
				Utils.clearFieldMarker(this.fieldsInError);
			}
			return this;		
		},
		
		savePlanValues : function() {
			if(this.model.get('selectedResource') == 0 || this.model.get('selectedProject') == 0 || this.model.attributes.errorMessage)
				return this;
			var that = this;
			var planValueModel = this.model;
			planValueModel.set('saved', "true");
			planValueModel.set('operation', "spreadInPeriod");
			planValueModel.save(null, {success:function(model, res, options) {
				that.options.contextModel.set('operation','refresh');
				that.options.contextModel.save();
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.saved.value.title");
				var replacements = {'%USER%': model.attributes.changedResource.displayName, '%PROJECT%': model.attributes.changedProject.name,'%FROM%': model.attributes.from,'%TO%': model.attributes.to };
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.saved.value.message");
				var message = Utils.replace(replacements,text);
				var flag = Utils.sendMessage('success',title,'auto',message);
				Utils.validateFlagModel(model,'naomi.templates.js.jirarp.board.message');
				
			},error:function(model, res, options) {
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.value.title");
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.value.message");
				var responseMessage = jQuery.parseJSON(res.responseText);
				var replacements = {'%RESPONSE_MESSAGE%' : responseMessage.message};
				var message = Utils.replace(replacements,text);
				Utils.sendMessage('error',title,'manual',message);
			}});				
			AJS.dialog2("#add-plan-value-dialog").hide();
		},

		cancelPlanValues : function() {
			AJS.dialog2("#add-plan-value-dialog").hide();
		},
		
		distributionSelectChanged : function(event) {
			var value = event.currentTarget.value;
			this.model.set('selectedDistribution', value);
			this.model.set('operation', "changeDistribution");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
			},error:function(model, res, options) {
				var responseMessage = jQuery.parseJSON(res.responseText);
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.distribution.change.title");
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.distribution.change.message");
				var replacements = {'%RESPONSE_MESSAGE%' : responseMessage.message};
				var message = Utils.replace(replacements,text);
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, message, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		projectSelectChanged : function(event) {
			var value = event.currentTarget.value;
			if( value != this.model.get('selectedProject') ){
				this.model.set('selectedResource', 0);
				this.model.set('selectedResourceChanged', "true");
			}
			this.model.set('selectedProject', value);
			this.model.set('selectedProjectChanged', "true");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
			},error:function(model, res, options) {
				var responseMessage = jQuery.parseJSON(res.responseText);
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.project.change.title");
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.project.change.message");
				var replacements = {'%RESPONSE_MESSAGE%' : responseMessage.message};
				var message = Utils.replace(replacements,text);
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, message, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},

		fromChanged : function(event) {
			var planValueModel = this.model;
			event.currentTarget.removeAttribute('data-aui-notification-error');
			var value = event.currentTarget.value;
			planValueModel.set('from', value);
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.set('selectedFromChanged', "true");
			planValueModel.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
			},error:function(model, res, options) {
				var responseMessage = jQuery.parseJSON(res.responseText);
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.from.change.title");
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.from.change.message");
				var replacements = {'%RESPONSE_MESSAGE%' : responseMessage.message};
				var message = Utils.replace(replacements,text);
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, message, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
				}});
		},
		
		toChanged : function(event) {
			var planValueModel = this.model;
			event.currentTarget.removeAttribute('data-aui-notification-error');
			var value = event.currentTarget.value;
			planValueModel.set('to', value);
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.set('selectedToChanged', "true");
			planValueModel.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
			},error:function(model, res, options) {
				var responseMessage = jQuery.parseJSON(res.responseText);
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.to.change.title");
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.to.change.message");
				var replacements = {'%RESPONSE_MESSAGE%' : responseMessage.message};
				var message = Utils.replace(replacements,text);
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, message, false, 5000, 500);	
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},
		
		planValueChanged : function(event) {
			var planValueModel = this.model;
			var value = event.currentTarget.value;
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			planValueModel.set('planValue', value);
			this.model.set('operation', "validatePlanValue");
			planValueModel.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
			},error:function(model, res, options) {
				var responseMessage = jQuery.parseJSON(res.responseText);
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.plan.value.change.title");
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.plan.value.change.message");
				var replacements = {'%RESPONSE_MESSAGE%' : responseMessage.message};
				var message = Utils.replace(replacements,text);
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, message, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		},
		
		resourceSelectChanged : function(event) {
			var value = event.currentTarget.value;
			this.model.set('selectedResource', value);	
			this.model.set('selectedResourceChanged', "true");
			var fieldHolder = this.fieldsInError;
			var selector = '#'+event.currentTarget.id;
			this.model.save(null, {success:function(model, res, options) {
				Utils.validateBarModel(model, 'naomi.templates.js.jirarp.board.message', '#add-dialog-message-bar', selector, fieldHolder);
			},error:function(model, res, options) {
				var responseMessage = jQuery.parseJSON(res.responseText);
				var title= AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.resource.change.title");
				var text = AJS.I18n.getText("naomi.templates.js.jirarp.plan.board.add.dialog.message.error.resource.change.message");
				var replacements = {'%RESPONSE_MESSAGE%' : responseMessage.message};
				var message = Utils.replace(replacements,text);
				Utils.sendBarErrorMessage('#add-dialog-message-bar', title, message, false, 5000, 500);
				Utils.markFieldWithError(selector, fieldHolder);
			}});
		}
	});
	return PlanValueView;
});